@@ -17,7 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Qgoda::Splitter;
-$Qgoda::Splitter::VERSION = 'v0.9.2';
+$Qgoda::Splitter::VERSION = 'v0.9.3';
 use strict;
 
 use Locale::TextDomain qw('qgoda');
@@ -58,9 +58,9 @@ sub new {
 
     my @first =  grep { !empty } split /
                 (
-                <!--QGODA-XGETTEXT-->(?:.*?)<!--\/QGODA-XGETTEXT-->
+                <!--qgoda-xgettext-->(?:.*?)<!--\/qgoda-xgettext-->
                 |
-                <!--QGODA-NO-XGETTEXT-->(?:.*?)<!--\/QGODA-NO-XGETTEXT-->
+                <!--qgoda-no-xgettext-->(?:.*?)<!--\/qgoda-no-xgettext-->
                 |
                 [ \011-\015]*
                 \n
@@ -87,13 +87,13 @@ sub new {
     my @entries;
     foreach my $chunk (@chunks) {
         if ($chunk =~ /[^ \011-\015]+$/) {
-            if ($chunk =~ /^<!--QGODA-XGETTEXT-->(.*?)<!--\/QGODA-XGETTEXT-->$/s) {
+            if ($chunk =~ /^<!--qgoda-xgettext-->(.*?)<!--\/qgoda-xgettext-->$/s) {
                 push @entries, {
                     text => $1,
                     lineno => $lineno,
                     type => 'block',
                 }
-            } elsif ($chunk =~ /^<!--QGODA-NO-XGETTEXT-->(.*?)<!--\/QGODA-NO-XGETTEXT-->$/s) {
+            } elsif ($chunk =~ /^<!--qgoda-no-xgettext-->(.*?)<!--\/qgoda-no-xgettext-->$/s) {
                 push @entries, {
                     text => $1,
                     lineno => $lineno,
@@ -176,13 +176,13 @@ sub reassemble {
         if ('whitespace' eq $entry->{type}) {
             $output .= $entry->{text};
         } elsif ('block' eq $entry->{type}) {
-            $output .= "<!--QGODA-XGETTEXT-->"
+            $output .= "<!--qgoda-xgettext-->"
                 . $callback->($entry->{text})
-                . "<!--/QGODA-XGETTEXT-->";
+                . "<!--/qgoda-xgettext-->";
         } elsif ('exclude' eq $entry->{type}) {
-            $output .= "<!--QGODA-NO-XGETTEXT-->"
+            $output .= "<!--qgoda-no-xgettext-->"
                 . $callback->($entry->{text})
-                . "<!--/QGODA-NO-XGETTEXT-->";
+                . "<!--/qgoda-no-xgettext-->";
         } else {
             $output .= $callback->($entry->{text});
         }
